@@ -22,10 +22,7 @@ use strict;
 use warnings;
 no warnings 'uninitialized';
 
-use base 'Plucene::Store::InputStream';    # And why not, indeed
 use Encode qw(encode);
-use constant BYTE => 2**8 - 1;
-use constant INT  => 2**32 - 1;
 
 =head2 new
 
@@ -34,10 +31,43 @@ Create a new Plucene::Store::OutputStream
 =cut
 
 sub new {
-	my ($self, $file) = @_;
-	shift->SUPER::new($file, "w");
+	my ($self, $filename) = @_;
+	$self = ref $self || $self;
+	open my $fh, '>', $filename
+		or die "$self cannot open $filename for writing: $!";
+	binmode $fh;
+	bless [ $fh, $filename ], $self;
 }
 
+=head2 clone
+
+Clone this
+
+=cut
+
+sub clone {
+	my $orig  = shift;
+	my $clone = $orig->new($orig->[1]);
+	CORE::seek($clone->[0], CORE::tell($orig->[0]), 0);
+	return $clone;
+}
+
+=head2 fh / read / seek / tell / getc / print / eof / close
+
+File operations
+
+=cut
+
+use Carp 'croak';
+sub fh    { croak "OutputStream fh called" }
+sub read  { croak "OutputStream read called" }
+sub seek  { CORE::seek $_[0]->[0], $_[1], $_[2] }
+sub tell  { CORE::tell $_[0]->[0] }
+sub getc  { croak "OutputStream getc called" }
+sub print { my $fh = shift->[0]; CORE::print $fh @_ }
+sub eof   { CORE::eof $_[0]->[0] }
+sub close { CORE::close $_[0]->[0] }
+
 =head2 write_byte
 
 This will write a single byte.
@@ -45,8 +75,7 @@ This will write a single byte.
 =cut
 
 sub write_byte {
-	my ($self, $b) = @_;
-	$self->print($b);
+	CORE::print { $_[0]->[0] } $_[1];
 }
 
 =head2 write_int
@@ -56,8 +85,7 @@ This will write an int as four bytes.
 =cut
 
 sub write_int {
-	my ($self, $i) = @_;
-	$self->print(pack("N", $i));
+	CORE::print { $_[0]->[0] } pack("N", $_[1]);
 }
 
 =head2 write_vint
@@ -67,13 +95,15 @@ This will write an int in a variable length format.
 =cut
 
 sub write_vint {
-	my ($self, $i) = @_;
-	$i += 0;
+	use bytes;
+	my $i = $_[1];
+	my $txt;
 	while ($i & ~0x7f) {
-		$self->print(chr(BYTE & (($i & 0x7f) | 0x80)));
+		$txt .= chr($i | 0x80);
 		$i >>= 7;
 	}
-	$self->print(chr(BYTE & $i));
+	$txt .= chr($i);
+	CORE::print { $_[0]->[0] } $txt;
 }
 
 =head2 write_long
@@ -83,8 +113,8 @@ This will write a long as eight bytes.
 =cut
 
 sub write_long {
-	my ($self, $i) = @_;
-	$self->print(pack("NN", INT & ($i >> 32), INT & $i));
+	CORE::print { $_[0]->[0] }
+		pack("NN", 0xffffffff & ($_[1] >> 32), 0xffffffff & $_[1]);
 }
 
 =head2 write_vlong
@@ -102,10 +132,10 @@ This will write a string.
 =cut
 
 sub write_string {
-	my ($self, $s) = @_;
+	my $s = $_[1];
 	$s = encode("utf8", $s) if $s =~ /[^\x00-\x7f]/;
-	$self->write_vint(length $s);
-	$self->print($s);
+	$_[0]->write_vint(length $s);
+	CORE::print { $_[0]->[0] } $s;
 }
 
 1;
